# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stock_real.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
import stock_comm_pb2 as stock__comm__pb2
import msg_comm_cust_pb2 as msg__comm__cust__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='stock_real.proto',
  package='Stock',
  syntax='proto3',
  serialized_options=b'\n#com.kaisaglobal.proto.stock.release\200\001\000\210\001\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10stock_real.proto\x12\x05Stock\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x10stock_comm.proto\x1a\x13msg_comm_cust.proto\"<\n\x04Rule\x12$\n\nstockCodes\x18\x01 \x03(\x0b\x32\x10.Stock.StockCode\x12\x0e\n\x06\x66ields\x18\x02 \x03(\t\"\x8c\x01\n\tStockCode\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12#\n\x06market\x18\x02 \x01(\x0e\x32\x13.StockCommon.Market\x12\'\n\x08language\x18\x03 \x01(\x0e\x32\x15.StockCommon.Language\x12#\n\x05types\x18\x04 \x03(\x0e\x32\x14.StockCommon.SubType\"\x84\x04\n\x05Quote\x12\x0e\n\x06market\x18\x01 \x01(\r\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0b\n\x03now\x18\x03 \x01(\x01\x12\x0c\n\x04open\x18\x04 \x01(\x01\x12\x0c\n\x04high\x18\x05 \x01(\x01\x12\x0b\n\x03low\x18\x06 \x01(\x01\x12\x12\n\nlast_close\x18\x07 \x01(\x01\x12\x0e\n\x06volume\x18\x08 \x01(\x04\x12\x0e\n\x06\x61mount\x18\t \x01(\x01\x12\x13\n\x0bupdate_flag\x18\n \x03(\r\x12.\n\nquote_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\trecv_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12$\n\ngrey_quote\x18\r \x01(\x0b\x32\x10.Stock.GreyQuote\x12\x15\n\rquantityRatio\x18\x0e \x01(\x01\x12\r\n\x05\x63lose\x18\x0f \x01(\x01\x12\x1f\n\x07tick_vi\x18\x10 \x01(\x0e\x32\x0e.Stock.Tick_VI\x12\x16\n\x0etrading_status\x18\x11 \x01(\t\x12\x10\n\x08modifier\x18\x12 \x01(\t\x12\x14\n\x0cpre5MinPrice\x18\x13 \x01(\x01\x12\x11\n\touterDisk\x18\x14 \x01(\x01\x12\x11\n\tinnerDisk\x18\x15 \x01(\x01\x12\x15\n\rnasdaq_volume\x18\x16 \x01(\x01\x12\x15\n\rnasdaq_amount\x18\x17 \x01(\x01\"d\n\tGreyQuote\x12\x17\n\x0f\x63ur_trade_count\x18\x01 \x01(\r\x12\x0f\n\x07lotSize\x18\x02 \x01(\r\x12\x16\n\x0eorderSellPrice\x18\x03 \x01(\x01\x12\x15\n\rorderBuyPrice\x18\x04 \x01(\x01\"C\n\x08TickList\x12\x0e\n\x06market\x18\x01 \x01(\r\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x19\n\x04tick\x18\x03 \x03(\x0b\x32\x0b.Stock.Tick\"\xf3\x01\n\x04Tick\x12\x0e\n\x06req_id\x18\x01 \x01(\r\x12\x0b\n\x03now\x18\x02 \x01(\x01\x12\x12\n\ncur_volume\x18\x03 \x01(\r\x12\x11\n\ttick_flag\x18\x04 \x01(\r\x12\x1f\n\x07tick_vi\x18\x05 \x01(\x0e\x32\x0e.Stock.Tick_VI\x12-\n\ttick_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\trecv_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0egrey_tick_time\x18\x08 \x01(\t\x12\x10\n\x08modifier\x18\t \x01(\t\"\xa6\x01\n\x0fOrderStallsList\x12\x0e\n\x06market\x18\x01 \x01(\r\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12%\n\torderSell\x18\x04 \x03(\x0b\x32\x12.Stock.OrderStalls\x12$\n\x08orderBuy\x18\x05 \x03(\x0b\x32\x12.Stock.OrderStalls\"Q\n\x0bOrderStalls\x12\r\n\x05level\x18\x01 \x01(\r\x12\r\n\x05price\x18\x02 \x01(\x01\x12\x0e\n\x06volume\x18\x03 \x01(\x04\x12\x14\n\x0c\x62roker_count\x18\x04 \x01(\r\"\xc8\x01\n\nBrokerList\x12\x0e\n\x06market\x18\x01 \x01(\r\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12(\n\x04time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12!\n\nbrokerSell\x18\x04 \x03(\x0b\x32\r.Stock.Broker\x12 \n\tbrokerBuy\x18\x05 \x03(\x0b\x32\r.Stock.Broker\x12-\n\trecv_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"1\n\x06\x42roker\x12\x14\n\x0c\x62roker_level\x18\x01 \x01(\r\x12\x11\n\tbroker_id\x18\x02 \x03(\t\"Z\n\nClearStock\x12\x0e\n\x06market\x18\x01 \x01(\r\x12\x12\n\nclear_flag\x18\x02 \x01(\r\x12\x14\n\x0cstock_status\x18\x03 \x01(\r\x12\x12\n\nstock_time\x18\x04 \x01(\t*S\n\x07Tick_VI\x12\x10\n\x0cTick_VI_None\x10\x00\x12\x05\n\x01X\x10\x01\x12\x05\n\x01\x44\x10\x02\x12\x05\n\x01R\x10\x03\x12\x05\n\x01M\x10\x04\x12\x05\n\x01N\x10\x05\x12\x05\n\x01Y\x10\x06\x12\x05\n\x01P\x10\x07\x12\x05\n\x01U\x10\x08*\xb6\x02\n\nUpdateFlag\x12\x07\n\x03now\x10\x00\x12\x08\n\x04open\x10\x01\x12\x08\n\x04high\x10\x02\x12\x07\n\x03low\x10\x03\x12\n\n\x06volume\x10\x04\x12\n\n\x06\x61mount\x10\x05\x12\x0e\n\nlast_close\x10\x06\x12\x13\n\x0f\x63ur_trade_count\x10\x07\x12\x0b\n\x07lotSize\x10\x08\x12\x12\n\x0eorderSellPrice\x10\t\x12\x11\n\rorderBuyPrice\x10\n\x12\x11\n\rquantityRatio\x10\x0b\x12\t\n\x05\x63lose\x10\x0c\x12\n\n\x06tickVi\x10\r\x12\x11\n\rtradingStatus\x10\x0e\x12\x10\n\x0cpre5MinPrice\x10\x0f\x12\r\n\touterDisk\x10\x10\x12\r\n\tinnerDisk\x10\x11\x12\x11\n\rnasdaq_volume\x10\x12\x12\x11\n\rnasdaq_amount\x10\x13\x42.\n#com.kaisaglobal.proto.stock.release\x80\x01\x00\x88\x01\x01\x90\x01\x00\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,stock__comm__pb2.DESCRIPTOR,msg__comm__cust__pb2.DESCRIPTOR,])

_TICK_VI = _descriptor.EnumDescriptor(
  name='Tick_VI',
  full_name='Stock.Tick_VI',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Tick_VI_None', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='X', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='D', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='R', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='M', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='N', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Y', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='P', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='U', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1838,
  serialized_end=1921,
)
_sym_db.RegisterEnumDescriptor(_TICK_VI)

Tick_VI = enum_type_wrapper.EnumTypeWrapper(_TICK_VI)
_UPDATEFLAG = _descriptor.EnumDescriptor(
  name='UpdateFlag',
  full_name='Stock.UpdateFlag',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='now', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='open', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='high', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='low', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='volume', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='amount', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='last_close', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='cur_trade_count', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='lotSize', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='orderSellPrice', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='orderBuyPrice', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='quantityRatio', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='close', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='tickVi', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='tradingStatus', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='pre5MinPrice', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='outerDisk', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='innerDisk', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='nasdaq_volume', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='nasdaq_amount', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1924,
  serialized_end=2234,
)
_sym_db.RegisterEnumDescriptor(_UPDATEFLAG)

UpdateFlag = enum_type_wrapper.EnumTypeWrapper(_UPDATEFLAG)
Tick_VI_None = 0
X = 1
D = 2
R = 3
M = 4
N = 5
Y = 6
P = 7
U = 8
now = 0
open = 1
high = 2
low = 3
volume = 4
amount = 5
last_close = 6
cur_trade_count = 7
lotSize = 8
orderSellPrice = 9
orderBuyPrice = 10
quantityRatio = 11
close = 12
tickVi = 13
tradingStatus = 14
pre5MinPrice = 15
outerDisk = 16
innerDisk = 17
nasdaq_volume = 18
nasdaq_amount = 19



_RULE = _descriptor.Descriptor(
  name='Rule',
  full_name='Stock.Rule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stockCodes', full_name='Stock.Rule.stockCodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fields', full_name='Stock.Rule.fields', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=159,
)


_STOCKCODE = _descriptor.Descriptor(
  name='StockCode',
  full_name='Stock.StockCode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='Stock.StockCode.code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market', full_name='Stock.StockCode.market', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='language', full_name='Stock.StockCode.language', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='types', full_name='Stock.StockCode.types', index=3,
      number=4, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=162,
  serialized_end=302,
)


_QUOTE = _descriptor.Descriptor(
  name='Quote',
  full_name='Stock.Quote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='Stock.Quote.market', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='Stock.Quote.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='now', full_name='Stock.Quote.now', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='open', full_name='Stock.Quote.open', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='high', full_name='Stock.Quote.high', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low', full_name='Stock.Quote.low', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_close', full_name='Stock.Quote.last_close', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='Stock.Quote.volume', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='Stock.Quote.amount', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_flag', full_name='Stock.Quote.update_flag', index=9,
      number=10, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_time', full_name='Stock.Quote.quote_time', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recv_time', full_name='Stock.Quote.recv_time', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grey_quote', full_name='Stock.Quote.grey_quote', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantityRatio', full_name='Stock.Quote.quantityRatio', index=13,
      number=14, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='close', full_name='Stock.Quote.close', index=14,
      number=15, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_vi', full_name='Stock.Quote.tick_vi', index=15,
      number=16, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trading_status', full_name='Stock.Quote.trading_status', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modifier', full_name='Stock.Quote.modifier', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pre5MinPrice', full_name='Stock.Quote.pre5MinPrice', index=18,
      number=19, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='outerDisk', full_name='Stock.Quote.outerDisk', index=19,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='innerDisk', full_name='Stock.Quote.innerDisk', index=20,
      number=21, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nasdaq_volume', full_name='Stock.Quote.nasdaq_volume', index=21,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nasdaq_amount', full_name='Stock.Quote.nasdaq_amount', index=22,
      number=23, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=821,
)


_GREYQUOTE = _descriptor.Descriptor(
  name='GreyQuote',
  full_name='Stock.GreyQuote',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cur_trade_count', full_name='Stock.GreyQuote.cur_trade_count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lotSize', full_name='Stock.GreyQuote.lotSize', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderSellPrice', full_name='Stock.GreyQuote.orderSellPrice', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderBuyPrice', full_name='Stock.GreyQuote.orderBuyPrice', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=823,
  serialized_end=923,
)


_TICKLIST = _descriptor.Descriptor(
  name='TickList',
  full_name='Stock.TickList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='Stock.TickList.market', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='Stock.TickList.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick', full_name='Stock.TickList.tick', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=925,
  serialized_end=992,
)


_TICK = _descriptor.Descriptor(
  name='Tick',
  full_name='Stock.Tick',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='req_id', full_name='Stock.Tick.req_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='now', full_name='Stock.Tick.now', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cur_volume', full_name='Stock.Tick.cur_volume', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_flag', full_name='Stock.Tick.tick_flag', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_vi', full_name='Stock.Tick.tick_vi', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tick_time', full_name='Stock.Tick.tick_time', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recv_time', full_name='Stock.Tick.recv_time', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grey_tick_time', full_name='Stock.Tick.grey_tick_time', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='modifier', full_name='Stock.Tick.modifier', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=995,
  serialized_end=1238,
)


_ORDERSTALLSLIST = _descriptor.Descriptor(
  name='OrderStallsList',
  full_name='Stock.OrderStallsList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='Stock.OrderStallsList.market', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='Stock.OrderStallsList.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='Stock.OrderStallsList.time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderSell', full_name='Stock.OrderStallsList.orderSell', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orderBuy', full_name='Stock.OrderStallsList.orderBuy', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1241,
  serialized_end=1407,
)


_ORDERSTALLS = _descriptor.Descriptor(
  name='OrderStalls',
  full_name='Stock.OrderStalls',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='level', full_name='Stock.OrderStalls.level', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='Stock.OrderStalls.price', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='Stock.OrderStalls.volume', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broker_count', full_name='Stock.OrderStalls.broker_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1409,
  serialized_end=1490,
)


_BROKERLIST = _descriptor.Descriptor(
  name='BrokerList',
  full_name='Stock.BrokerList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='Stock.BrokerList.market', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='Stock.BrokerList.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='Stock.BrokerList.time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brokerSell', full_name='Stock.BrokerList.brokerSell', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brokerBuy', full_name='Stock.BrokerList.brokerBuy', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='recv_time', full_name='Stock.BrokerList.recv_time', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1493,
  serialized_end=1693,
)


_BROKER = _descriptor.Descriptor(
  name='Broker',
  full_name='Stock.Broker',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='broker_level', full_name='Stock.Broker.broker_level', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='broker_id', full_name='Stock.Broker.broker_id', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1695,
  serialized_end=1744,
)


_CLEARSTOCK = _descriptor.Descriptor(
  name='ClearStock',
  full_name='Stock.ClearStock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='Stock.ClearStock.market', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_flag', full_name='Stock.ClearStock.clear_flag', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stock_status', full_name='Stock.ClearStock.stock_status', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stock_time', full_name='Stock.ClearStock.stock_time', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1746,
  serialized_end=1836,
)

_RULE.fields_by_name['stockCodes'].message_type = _STOCKCODE
_STOCKCODE.fields_by_name['market'].enum_type = stock__comm__pb2._MARKET
_STOCKCODE.fields_by_name['language'].enum_type = stock__comm__pb2._LANGUAGE
_STOCKCODE.fields_by_name['types'].enum_type = stock__comm__pb2._SUBTYPE
_QUOTE.fields_by_name['quote_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_QUOTE.fields_by_name['recv_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_QUOTE.fields_by_name['grey_quote'].message_type = _GREYQUOTE
_QUOTE.fields_by_name['tick_vi'].enum_type = _TICK_VI
_TICKLIST.fields_by_name['tick'].message_type = _TICK
_TICK.fields_by_name['tick_vi'].enum_type = _TICK_VI
_TICK.fields_by_name['tick_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TICK.fields_by_name['recv_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ORDERSTALLSLIST.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ORDERSTALLSLIST.fields_by_name['orderSell'].message_type = _ORDERSTALLS
_ORDERSTALLSLIST.fields_by_name['orderBuy'].message_type = _ORDERSTALLS
_BROKERLIST.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BROKERLIST.fields_by_name['brokerSell'].message_type = _BROKER
_BROKERLIST.fields_by_name['brokerBuy'].message_type = _BROKER
_BROKERLIST.fields_by_name['recv_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Rule'] = _RULE
DESCRIPTOR.message_types_by_name['StockCode'] = _STOCKCODE
DESCRIPTOR.message_types_by_name['Quote'] = _QUOTE
DESCRIPTOR.message_types_by_name['GreyQuote'] = _GREYQUOTE
DESCRIPTOR.message_types_by_name['TickList'] = _TICKLIST
DESCRIPTOR.message_types_by_name['Tick'] = _TICK
DESCRIPTOR.message_types_by_name['OrderStallsList'] = _ORDERSTALLSLIST
DESCRIPTOR.message_types_by_name['OrderStalls'] = _ORDERSTALLS
DESCRIPTOR.message_types_by_name['BrokerList'] = _BROKERLIST
DESCRIPTOR.message_types_by_name['Broker'] = _BROKER
DESCRIPTOR.message_types_by_name['ClearStock'] = _CLEARSTOCK
DESCRIPTOR.enum_types_by_name['Tick_VI'] = _TICK_VI
DESCRIPTOR.enum_types_by_name['UpdateFlag'] = _UPDATEFLAG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Rule = _reflection.GeneratedProtocolMessageType('Rule', (_message.Message,), {
  'DESCRIPTOR' : _RULE,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.Rule)
  })
_sym_db.RegisterMessage(Rule)

StockCode = _reflection.GeneratedProtocolMessageType('StockCode', (_message.Message,), {
  'DESCRIPTOR' : _STOCKCODE,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.StockCode)
  })
_sym_db.RegisterMessage(StockCode)

Quote = _reflection.GeneratedProtocolMessageType('Quote', (_message.Message,), {
  'DESCRIPTOR' : _QUOTE,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.Quote)
  })
_sym_db.RegisterMessage(Quote)

GreyQuote = _reflection.GeneratedProtocolMessageType('GreyQuote', (_message.Message,), {
  'DESCRIPTOR' : _GREYQUOTE,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.GreyQuote)
  })
_sym_db.RegisterMessage(GreyQuote)

TickList = _reflection.GeneratedProtocolMessageType('TickList', (_message.Message,), {
  'DESCRIPTOR' : _TICKLIST,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.TickList)
  })
_sym_db.RegisterMessage(TickList)

Tick = _reflection.GeneratedProtocolMessageType('Tick', (_message.Message,), {
  'DESCRIPTOR' : _TICK,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.Tick)
  })
_sym_db.RegisterMessage(Tick)

OrderStallsList = _reflection.GeneratedProtocolMessageType('OrderStallsList', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSTALLSLIST,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.OrderStallsList)
  })
_sym_db.RegisterMessage(OrderStallsList)

OrderStalls = _reflection.GeneratedProtocolMessageType('OrderStalls', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSTALLS,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.OrderStalls)
  })
_sym_db.RegisterMessage(OrderStalls)

BrokerList = _reflection.GeneratedProtocolMessageType('BrokerList', (_message.Message,), {
  'DESCRIPTOR' : _BROKERLIST,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.BrokerList)
  })
_sym_db.RegisterMessage(BrokerList)

Broker = _reflection.GeneratedProtocolMessageType('Broker', (_message.Message,), {
  'DESCRIPTOR' : _BROKER,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.Broker)
  })
_sym_db.RegisterMessage(Broker)

ClearStock = _reflection.GeneratedProtocolMessageType('ClearStock', (_message.Message,), {
  'DESCRIPTOR' : _CLEARSTOCK,
  '__module__' : 'stock_real_pb2'
  # @@protoc_insertion_point(class_scope:Stock.ClearStock)
  })
_sym_db.RegisterMessage(ClearStock)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
import sys
import time, struct
from os.path import dirname, abspath
import requests, datetime
import pandas as pd
import numpy as np
import json, uuid, socket
from ctypes import *
from com import *
'''Date: 2021.03.15'''

from py_protoc import msg_comm_request_pb2 as msg_stock_common
from py_protoc import msg_comm_cust_pb2 as cust_pb
from py_protoc import msg_comm_response_pb2 as reponse_pb
from py_protoc import stock_comm_pb2 as comm_pb
from py_protoc import stock_real_pb2 as msg_stock    # real_pb
from py_protoc import stock_his_pb2 as msg_his_stock
def get_mac_addr():
    # 获取Mac地址
    macaddr = uuid.UUID(int=uuid.getnode()).hex[-12:]
    return ":".join([macaddr[e:e+2] for e in range(0, 11, 2)])

def get_ip_addr():
    # 获取本机ip
    # 获取电脑名称
    this_name = socket.getfqdn(socket.gethostname())
    # 获取IP
    ip = socket.gethostbyname(this_name)
    return ip



def total_handle_req(body, URL):
    response = requests.request(
        method='POST',
        url=URL,
        headers={'Content-Type': 'application/json'},
        params=None,
        data=json.dumps(body),
    )
    resp_data = response.json()
    resp_status = resp_data['success']

    if resp_status is False:
        return pd.DataFrame()
    try:
        _df_ = pd.DataFrame(resp_data['body']['data'])
    except:
        _df_ = (resp_data['body'])

    return _df_

def handle_hist_data_req_pages(body, URL):
    # 历史行情数据
    response = requests.request(
        method='POST',
        url=URL,
        headers={'Content-Type': 'application/json'},
        params=None,
        data=json.dumps(body),
    )
    try:
        resp_data = response.json()
        resp_status = resp_data['success']

        if resp_status is False:
            return pd.DataFrame()
        try:
            pages = resp_data['body']['pages']
            return pages
        except:
            ret = resp_data['body']
            return ret
    except Exception as exp:
        return '您好, 您填入的参数有误(response.status:{}), 请检查后重新请求!'.format(response.status_code)

def total_handle_hist_data_req(body, URL):
    response = requests.request(
        method='POST',
        url=URL,
        headers={'Content-Type': 'application/json'},
        params=None,
        data=json.dumps(body),
    )
    resp_data = response.json()
    resp_status = resp_data['success']

    if resp_status is False:
        return pd.DataFrame()
    try:
        __ = resp_data['body']['records']
        return __
    except:
        ret = resp_data['body']
        return ret

def change_timestamp(ts):
    # change ts
    ts = int(str(ts)[:10])
    timeArray = time.localtime(int(ts))
    _date_ = time.strftime("%Y-%m-%d %H:%M:%S", timeArray)
    return _date_

def t_typeof(variate):
    '''
    返回变量的类型
    '''

    type = None
    if isinstance(variate, int):
        type = "int"
    elif isinstance(variate, str):
        type = "str"
    elif isinstance(variate, float):
        type = "float"
    elif isinstance(variate, list):
        type = "list"
    elif isinstance(variate, tuple):
        type = "tuple"
    elif isinstance(variate, dict):
        type = "dict"
    elif isinstance(variate, set):
        type = "set"
    return type


# ResHead头定义
class IPResHead(Structure):
    _fields_ = [
        ("ihl", c_ubyte, 4),
        ("version", c_ubyte, 4),
        ("tos", c_ubyte),
        ("len", c_ushort),
        ("id", c_ushort),
        ("offset", c_ushort),
        ("ttl", c_ubyte),
        ("protocol_num", c_ubyte),
        ("sum", c_ushort),
        ("src", c_uint),
        ("dst", c_uint),
    ]

    def __new__(self, socket_buffer=None):
        return self.from_buffer_copy(socket_buffer)

    def __init__(self, socket_buffer=None):
        self.protocol_map = {1: "ICMP", 6: "TCP", 17: "UDP"}
        # readable ip address
        self.src_address = socket.inet_ntoa(struct.pack("<I", self.src))
        self.dst_address = socket.inet_ntoa(struct.pack("<I", self.dst))
        # type of protocol
        try:
            self.protocol = self.protocol_map[self.protocol_num]
        except:
            self.protocol = str(self.protocol_num)


def get_respdata(data=None):
    head = data[0:28]
    respheat = struct.unpack('>hhhihihhii', head)
    mod = respheat[6]
    cmd = respheat[7]

    datalen = respheat[9]
    rspdata = ''
    if mod == 20 and cmd == 0:
        rspdata=''

    elif mod == 4 and cmd ==21:
        rspdata = rsp_HandicapQuotaResp(data[28:])
        #mssg = eum.cmd_mod(mod, cmd, rspdata)

    elif mod == 7 and cmd == 300:
        rspdata = rsp_TransactionStatResp(data[28:])
        #eum.cmd_mod(mod, cmd, rspdata)

    elif mod == 4 and cmd == 22:
        rspdata = rsp_KlineQuoteResp(data[28:])
        #eum.cmd_mod(mod, cmd, rspdata)

    elif mod == 4 and cmd == 23:
        rspdata = rsp_TickResp(data[28:])
        #eum.cmd_mod(mod, cmd, rspdata)

    elif mod == 4 and cmd == 24:
        rspdata = rsp_MinuteQuoteResp(data[28:])
        #eum.cmd_mod(mod, cmd, rspdata)

    elif mod ==5 and cmd in [100,101,102,105,106,107]:
        rspdata = rsp_SubMarketPlateReq(data[28:])
        #eum.cmd_mod(mod, cmd, rspdata)

# -----------------  订阅  ---------------------------------------

    elif mod == 1 and cmd == 1:
        # 分比数据
        # rspdata = rsp_Quote(data[28:])
        # eum.cmd_mod(mod, cmd, rspdata)
        rspdata = rsp_Quote(data[28:datalen + 28])
        #message = eum.cmd_mod(mod, cmd, rspdata)
        # print(message)
        surplus_data = data[datalen + 28:]
        if len(surplus_data) >= 28:
            get_respdata(data=surplus_data)

    # 订阅tick
    elif mod == 1 and cmd == 2:
        # 基础行情数据（返回）
        rspdata = rsp_TickList(data[28:datalen+28])

        now = rspdata.tick[0].now
        cur_volume = rspdata.tick[0].cur_volume
        tick_flag = rspdata.tick[0].tick_flag
        if rspdata.tick[0].tick_time.seconds:
            timeArray = time.localtime(rspdata.tick[0].tick_time.seconds)
            ns = int(rspdata.tick[0].tick_time.nanos / 10000) % 1000
        else:
            timeArray = time.localtime(rspdata.tick[0].recv_time.seconds)
            ns = int(rspdata.tick[0].recv_time.nanos / 10000) % 1000
        tick_time = time.strftime("%Y-%m-%d %H:%M:%S", timeArray)
        quote_time = str(tick_time)+'.'+str(ns)
        time_now = time.time()
        if rspdata.tick[0].tick_time.seconds:
            tick_time = rspdata.tick[0].tick_time.seconds + rspdata.tick[0].tick_time.nanos / 1000000000
        else:
            tick_time = rspdata.tick[0].recv_time.seconds + rspdata.tick[0].recv_time.nanos / 1000000000

        # if rspdata.market in (1, 2, 10, 11):
        #     alltime = cf.time_difference(time_now, tick_time)
        # else:
        #     alltime = cf.time_difference(time_now,tick_time) - 12*3600*1000
        # loginfo = rspdata.code + ':'+quote_time.ljust(26)+str(now).ljust(10)+ str(cur_volume).ljust(5) + str(tick_flag)+ '    延迟时间：'+str(int(alltime))+'ms'
        #log.info(loginfo)
        #eum.cmd_mod(mod, cmd, rspdata)
        surplus_data = data[datalen+28:]
        if len(surplus_data) >= 28:
            get_respdata(data=surplus_data)

    elif mod == 1 and cmd == 3:
        # 经纪人队列数据
        # rspdata = rsp_BrokerList(data[28:])
        # eum.cmd_mod(mod, cmd, rspdata)
        rspdata = rsp_BrokerList(data[28:datalen + 28])
        # message = eum.cmd_mod(mod, cmd, rspdata)
        surplus_data = data[datalen + 28:]
        if len(surplus_data) >= 28:
            get_respdata(data=surplus_data)

    elif mod == 1 and cmd == 4:
        # 买卖档数据
        rspdata = rsp_OrderStallsList(data[28:datalen + 28])
        # message = eum.cmd_mod(mod, cmd, rspdata)
        surplus_data = data[datalen + 28:]
        if len(surplus_data) >= 28:
            get_respdata(data=surplus_data)

    return cmd, rspdata

# --------------   拉取数据返回   ---------------------------------------

# 盘口响应解析
def rsp_HandicapQuotaResp(data):
    user_out = msg_his_stock.HandicapQuotaResp()
    user_out.ParseFromString(data)
    return user_out

# 成交统计数据（返回）
def rsp_TransactionStatResp(data):
    user_out = msg_his_stock.TransactionStatResp()
    user_out.ParseFromString(data)
    return user_out

# K线数据（返回）
def rsp_KlineQuoteResp(data):
    user_out = msg_his_stock.KlineQuoteResp()
    user_out.ParseFromString(data)
    return user_out

# tick数据（返回）
def rsp_TickResp(data):
    user_out = msg_his_stock.TickResp()
    user_out.ParseFromString(data)
    return user_out

def rsp_MinuteQuoteResp(data):
    user_out = msg_his_stock.MinuteQuoteResp()
    user_out.ParseFromString(data)
    return user_out

# --------------   订阅数据返回   ---------------------------------------
# 基础行情数据（返回）
def rsp_Quote(data):
    user_out = msg_stock.Quote()
    user_out.ParseFromString(data)
    return user_out

# 分比数据（返回）
def rsp_TickList(data):
    # print(' 分比数据（返回）:',data)
    user_out = msg_stock.TickList()
    user_out.ParseFromString(data)
    return user_out

# 经纪人队列数据（返回）
def rsp_BrokerList(data):
    user_out = msg_stock.BrokerList()
    user_out.ParseFromString(data)
    return user_out

# 买卖盘数据（返回）
def rsp_OrderStallsList(data):
    user_out = msg_stock.OrderStallsList()
    user_out.ParseFromString(data)
    return user_out

def rsp_SubMarketPlateReq(data):
    user_out = msg_his_stock.SubMarketAssetInfoResp()
    user_out.ParseFromString(data)
    return user_out


if __name__ == '__main__':
    pass
    # get_TransactionStatReq()
    # code_list=[{'code':'00700'},{'code':'01638'}]
    # HandicapQuotaReq(mod = 4, cmd = 21,symbollist = code_list)


# -*- coding:utf-8 -*-

# ===================================================================
# This file is used to store all paths and URLs in the interface document
# KaisaGlobal rights are reserved.
# ===================================================================


"""
This code provide utils function for KaisaGlobal-Open.
developed by KaisaGlobal quant team.
2021.03.02
"""
appendIpAddress = "192.168.1.1"
# appendIpAddress = None
OPENIP = '120.78.227.40'
OPENPORT = 28880
PHONEMODEL = 'Windows 10'
PLATFORM = 'Windows'
SRVTYPE = 'open'
EP = ''
SYSVERSION = '1.3.0'

##########################################
#### pro
# REAL ENV.
KAISA_ROOT_URL_REAL = "kgl.jt00000.com"

KAISA_ROOT_URL = KAISA_ROOT_URL_REAL
##########################################

# KAISA_ROOT_URL = KAISA_ROOT_URL_SIM
KAISA_ROOT_URL_API = "openapi.jt00000.com"

# # AUTHENTICA_URL = "https://openapi.jt00000.com"

## pro
CRYPTO_RSA_URL = "https://__kaisarooturl__/kgl-third-authorization/crypto/key/RSA"

## pro
AUTHENTICA_URL = "https://__kaisarooturl__/kgl-third-authorization/oauth/token"

## userid-pro
AU_USERID_URL = 'https://__kaisarooturl__/kgl-user-center/userRegInfo/selectLoginUserInfo'
QUOTE_URL = "https://kgl.jt00000.com/hq"

REST_DATA_HOST = "https://__kaisarooturl__/dzApp/dzHttpApi"

TRADE_CRYPTO_RSA_URL = "https://__kaisarooturl__/kgl-trade-service/crypto/key/RSA"
ClientByMobile_URL = "https://__kaisarooturl__/kgl-user-center/userOaccAccount/selectClientIdByMobile"
REST_HOST = "https://__kaisarooturl__/kgl-trade-service"
WEBSOCKET_TRADE_HOST = "wss://__kaisarooturl__/kgl-trade-push-service/ws"

openapi_scope = "wthk"
openapi_scope = "read"

# 港股tick历史数据URL
HK_STOCK_TICK_POST_URL = 'https://__kaisarooturl__/kgl-stock-support-provider/stock/quote/tickHistory/v2'
# 港股KLine历史数据URL
HK_STOCK_KLINE_POST_URL = 'https://__kaisarooturl__/kgl-stock-support-provider/quoteInfo/kLineHistory/v2'
# 港股盘口十档历史数据URL
HK_STOCK_LEVEL2_10_ORDER_URL = 'https://__kaisarooturl__/kgl-stock-support-provider/quoteInfo/orderBuySellHisList/v2'
# 港股经纪人历史数据URL
HK_STOCK_BROKER_URL = 'https://__kaisarooturl__/kgl-stock-support-provider/quoteInfo/brokerHisList/v2'


# 基础财务指标URL, Post
BASIC_FIN_POST_URL = "https://__kaisarooturl__/kgl-glidata-center/stockReport/finReport"
# 衍生财务指标URL，Post
EX_FIN_POST_URL = "http://__kaisarooturl__/kgl-stock-front-stoacq/openapi/financial/factor"
# 基础/衍生技术面因子URL，Post
BE_TECH_POST_URL = "http://__kaisarooturl__/kgl-stock-front-stoacq/openapi/stock/techindex"

START_PUSH = 200
STOP_PUSH = 201
SYNCHRONIZE_PUSH = 250
QUERY_HISTORY = 36
QUERY_CONTRACT = 52
ON_TICK = 251
ON_MARKETDATA = 153
PING = 2
PONG = 3
LOGIN = 10
HKSE_MARKET = 2002

CREATION = 101
UPDATE = 102
TRADE = 103
CANCELLATION = 104
ACCOUT = 106
POSITION = 105


#########################公共Error返回值
PUB_SMALLENDDATE_ERROR = '您好,检测到end_date比start_date要小哟,请修正后重新请求数据!'
PUB_DATENONE_ERROR = '您好,检测到end_date和start_date都为None,请修正后重新请求数据!'
PUB_WRONG_MSG_ERROR = "您好!您输入的参数有误, 请纠正后重新输入!"
PUB_ONLY_LIST_TYPE_ERROR = '请传入list类型的code_list字段'
PUB_WRONG_DATE_AROUND_ERROR = '您好, 检测到时间区间的存在问题, 导致取到的数据为空, 请修改时间后重新请求数据.'
PUB_HELLO = '您好'
PUB_SOR = '抱歉'
#########################公共Error返回值



############################ KaisaHistQuoteData接口
########################### 一般常量
QUOTE_TYPE_DICT_ORI = {"1m": 1, "3m": 2, "5m": 3, "10m": 4, "15m": 5, "30m": 6, "1h": 7, "2h": 8, "4h": 9,
                       "1d": 10, "5d": 11, "1w": 12, "1M": 13, "1q": 14, "1y": 15}
ORI_DATA_TYPE_LIST = ['Kline', 'ticker', 'broker', 'level10']
HistQuote_MARKET_DICT = {1: 'CN', 2: 'HK', 3: 'US'}
K_QUOTE_TYPE_DICT = {"1m": 1, "1d": 10}
Quote_MARKET_DICT = {1: 'CN', 2: 'HK', 3: 'US'}
FRE_PRE_DICT = {'pre': '1', 'post': '2', 'None': '0'}

## 订阅的数据类型
SUB_QUOTE_TYPE = {'SUB_TYPE_NONE': 0, 'QUOTE': 1, 'TICK': 2, 'BROKER': 3, 'ORDER': 4}
QUOTE = 1   ## 盘口行情数据
TICK = 2    ## 逐笔行情数据
BROKERS = 3  ## 经纪商行情数据
LEVEL_ORDER = 4   ## 盘口十档行情数据
ALLDATAIDLIST=[1, 2, 3, 4]
PROTODATADIC = {1: 'QUOTE', 2: 'TICK', 3: 'BROKER', 4: 'ORDER'}
#################################################

KLINE = 'Kline'
KLINE_ORI_COLS = ['assetId', 'open', 'low', 'high', 'close', 'volume', 'amount', 'timestamp']
KLINE_RES_COLS = ['code', 'open', 'high', 'low', 'close', 'volume', 'money', 'trading_day']
KLINE_TIMESTAMP = 'timestamp'
KLINE_TRADEDATE = 'trading_day'
TICKER = 'ticker'
TICKER_ORI_COLS = ['assetId', 'now', 'curVolume', 'amount', 'tickFlag', 'tickVi', 'quoteTime']
TICKER_RES_COLS = ['code', 'last_price', 'volume', 'money', 'tick_order_type', 'tick_trade_type', 'quote_time']
BROKER = 'broker'
BROKER_ORI_COLS = ['assetId', 'brokerIdList', 'flag', 'level', 'brokerTime']
BROKER_RES_COLS = ['code', 'broker_id_list', 'direction', 'level', 'broker_time']
LEVEL10 = 'level10'
LEVEL10_ORI_COLS = ['assetId', 'price', 'flag', 'volume', 'brokerCount', 'level', 'quoteTime']
LEVEL10_RES_COLS = ['code', 'price', 'direction', 'volume', 'broker_count', 'level', 'quote_time']

############################ KaisaHistQuoteData接口里的Error异常备注##############################
MORECODES_ERROR = "您好, ticker接口限定每次只能拉取一个合约的数据, 请修改(如: code_list=['00700'])参数后重新请求!"
LOSSCODES_ERROR = '您好, 请填写您要获取数据的合约代码!'
ONLY_HK_MARKET_ERROR = '您好,接口暂时只提供港股、A股和美股的数据哟,我们会马不停蹄的加班,尽快把缺漏的数据补全!'
DATETYPE_ERROR = "您好, 请正确填写您要提取数据的参数, 如: data_type='Kline'"
OUTDATEFOR10_ERROR = '您好,单只股票,接口一次最多只能提供10年的数据哟,如果需要更多的数据,请分段获取!'
OUTDATEFOR1MON_ERROR = '您好,多只股票,接口一次最多只能提供1个月的数据哟,如果需要更多的数据,请分段获取!'
WRIONGUNIT_ERROR = "您好, 检测到您填写的unit参数不在允许范围内,参考:unit: '1m' or '1d'!"
FRE_ERROR = "您好, 请正确填写是否复权参数, 如: fre='pre'"
ONEDAYUPDATE_ERROR = '接口一次最多只能提供1个交易日的数据哟,如果需要更多的数据,请分段获取!'
#FIN_DATENONE_ERROR = '您好,检测到end_date和start_date都是None,请修正后重新请求数据!'

############################ KaisaHistQuoteData接口里的Error异常备注##############################

######################### KaisaHistQuoteData接口


############################ KaisaFinaData接口备注##############################
########################### 一般常量
FIN_MARKET_TYPE_DICT = {1: 'chn', 2: 'hkg', 3: 'usa'}
BASE_FACE = 'baseFace'
PROFIT = 'profit'
CASHFLOW = 'cashFlow'
OPERATION = 'operation'
DEBTPAY = 'debtPay'
GROWTH = 'growth'


############################ KaisaFinaData接口里的Error异常备注##############################
FIN_NOE_CODE_ERROR = '您好,该财务数据接口只允许获取单个合约的数据喔'
FIN_LOSS_CODE_ERROR = '您好, 请填写code字段！'

############################ KaisaFinaData接口里的Error异常备注##############################


############################ KaisaFinaData接口备注##############################


############################ KaisaTechData接口备注##############################

############################ KaisaTechData接口ERROR##############################
TECH_ONLY_DAY_DATA_ERROR = '您好,接口暂时不提供日级别以外的数据哟,我们会马不停蹄的加班,尽快把分钟、周和月级别的数据补全!'
TECH_ONLY_1_YEAR_DATA_ERROR = '您好,技术指标接口一次最多只能提供1年的数据哟,如果需要更多的数据,请分段获取!'
############################ KaisaTechData接口ERROR##############################

############################ KaisaTechData接口备注##############################


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stock_comm.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='stock_comm.proto',
  package='StockCommon',
  syntax='proto3',
  serialized_options=b'\n#com.kaisaglobal.proto.stock.release\200\001\000\210\001\001\220\001\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x10stock_comm.proto\x12\x0bStockCommon\"\xce\x01\n\x05Login\x12\r\n\x05token\x18\x01 \x01(\t\x12\x10\n\x08\x64\x65viceId\x18\x02 \x01(\t\x12\x12\n\nmacAddress\x18\x03 \x01(\t\x12\x11\n\tipAddress\x18\x04 \x01(\t\x12\x12\n\nsysVersion\x18\x05 \x01(\t\x12\x10\n\x08platform\x18\x06 \x01(\t\x12\x12\n\nphoneModel\x18\x07 \x01(\t\x12\x0f\n\x07srvType\x18\x08 \x01(\t\x12\x10\n\x08username\x18\t \x01(\t\x12\x10\n\x08password\x18\n \x01(\t\x12\x0e\n\x06userId\x18\x0b \x01(\t*\xa8\x01\n\x03Mod\x12\x0c\n\x08MOD_NONE\x10\x00\x12\x07\n\x03SUB\x10\x01\x12\x0e\n\nHEART_BEAT\x10\x03\x12\t\n\x05LOGIN\x10\x14\x12\x0c\n\x08HANDICAP\x10\x04\x12\t\n\x05PLATE\x10\x05\x12\r\n\tASSETINFO\x10\x06\x12\r\n\tTRANS_STA\x10\x07\x12\x0c\n\x08\x44\x41TA_DIC\x10\x08\x12\x10\n\x0cQUANT_FACTOR\x10\t\x12\n\n\x06\x41\x43TION\x10\x64\x12\x0c\n\x07RAM_MOD\x10\xc8\x01*H\n\x07SubType\x12\x11\n\rSUB_TYPE_NONE\x10\x00\x12\t\n\x05QUOTE\x10\x01\x12\x08\n\x04TICK\x10\x02\x12\n\n\x06\x42ROKER\x10\x03\x12\t\n\x05ORDER\x10\x04*\xa9\x04\n\x03\x43md\x12\x0c\n\x08\x43MD_NONE\x10\x00\x12\x0c\n\x08SubQuote\x10\n\x12\x0e\n\nUnSubQuote\x10\x0b\x12\x11\n\rHandicapQuota\x10\x15\x12\t\n\x05Kline\x10\x16\x12\x0c\n\x08TickInfo\x10\x17\x12\x0f\n\x0bMinuteQuote\x10\x18\x12\x0f\n\x0b\x42uySellList\x10\x19\x12\x0e\n\nBrokerInfo\x10\x1a\x12\x10\n\x0cHistoryKline\x10\x1b\x12\x13\n\x0fHistoryTickInfo\x10\x1c\x12\x13\n\x0fPopularIndustry\x10\x64\x12\x12\n\x0ePopularConcept\x10\x65\x12\x12\n\x0e\x41llSectorQuota\x10\x66\x12\x11\n\rIndustryQuota\x10g\x12\x10\n\x0c\x43onceptQuota\x10h\x12\x0e\n\nIndexQuota\x10i\x12\x14\n\x10IndexConstituent\x10j\x12\x13\n\x0fNewSharesListed\x10k\x12\x0b\n\x07Warrant\x10l\x12\x0b\n\x07\x41hStock\x10m\x12\x14\n\x10WarrantAssetInfo\x10n\x12\x13\n\x0e\x42\x61sicAssetInfo\x10\xc8\x01\x12\x17\n\x12\x42\x61sicSubMarketInfo\x10\xc9\x01\x12\x18\n\x13\x41ssetInfoByCodeList\x10\xca\x01\x12\x14\n\x0fTransactionStat\x10\xac\x02\x12\x0c\n\x07\x44icData\x10\x90\x03\x12\x14\n\x0fSTOCK_BACK_TEST\x10\x85\x07\x12\x0f\n\nClearStock\x10\xf4\x03\x12\x11\n\x0c\x45xchangeRate\x10\xf5\x03*\x9b\x01\n\x04\x43ode\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0e\n\nNO_INVOKER\x10\x01\x12\x12\n\x0e\x41GRUMENT_ERROR\x10\x02\x12\x14\n\x10UNKOWN_EXCEPTION\x10\x03\x12\x12\n\x0ePASSWARD_ERROR\x10\x04\x12\r\n\tHAS_LOGIN\x10\x05\x12\x0e\n\nLOGIN_FAIL\x10\x06\x12\x0c\n\x08NO_LOGIN\x10\x07\x12\x0b\n\x07TIMEOUT\x10\x08*j\n\x06Market\x12\x08\n\x04NONE\x10\x00\x12\x06\n\x02\x43N\x10\x01\x12\x06\n\x02HK\x10\x02\x12\x06\n\x02US\x10\x03\x12\x06\n\x02QS\x10\x1e\x12\x06\n\x02NS\x10\x1f\x12\x06\n\x02\x41S\x10 \x12\x06\n\x02PS\x10!\x12\x06\n\x02\x42S\x10\"\x12\x06\n\x02VS\x10#\x12\x06\n\x02SH\x10\n\x12\x06\n\x02SZ\x10\x0b*\"\n\x08Language\x12\x06\n\x02ZH\x10\x00\x12\x06\n\x02TW\x10\x01\x12\x06\n\x02\x45N\x10\x02*\xb9\x01\n\tQuoteType\x12\x08\n\x04NULL\x10\x00\x12\x08\n\x04MIN1\x10\x01\x12\x08\n\x04MIN3\x10\x02\x12\x08\n\x04MIN5\x10\x03\x12\t\n\x05MIN10\x10\x04\x12\t\n\x05MIN15\x10\x05\x12\t\n\x05MIN30\x10\x06\x12\t\n\x05HOUR1\x10\x07\x12\t\n\x05HOUR2\x10\x08\x12\t\n\x05HOUR4\x10\t\x12\x08\n\x04\x44\x41Y1\x10\n\x12\x08\n\x04\x44\x41Y5\x10\x0b\x12\t\n\x05WEEK1\x10\x0c\x12\n\n\x06MONTH1\x10\r\x12\x0c\n\x08QUARTER1\x10\x0e\x12\t\n\x05YEAR1\x10\x0f\x42.\n#com.kaisaglobal.proto.stock.release\x80\x01\x00\x88\x01\x01\x90\x01\x00\x62\x06proto3'
)

_MOD = _descriptor.EnumDescriptor(
  name='Mod',
  full_name='StockCommon.Mod',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MOD_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SUB', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEART_BEAT', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOGIN', index=3, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HANDICAP', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PLATE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ASSETINFO', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANS_STA', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DATA_DIC', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUANT_FACTOR', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTION', index=10, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RAM_MOD', index=11, number=200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=243,
  serialized_end=411,
)
_sym_db.RegisterEnumDescriptor(_MOD)

Mod = enum_type_wrapper.EnumTypeWrapper(_MOD)
_SUBTYPE = _descriptor.EnumDescriptor(
  name='SubType',
  full_name='StockCommon.SubType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUB_TYPE_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUOTE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TICK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BROKER', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ORDER', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=413,
  serialized_end=485,
)
_sym_db.RegisterEnumDescriptor(_SUBTYPE)

SubType = enum_type_wrapper.EnumTypeWrapper(_SUBTYPE)
_CMD = _descriptor.EnumDescriptor(
  name='Cmd',
  full_name='StockCommon.Cmd',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CMD_NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SubQuote', index=1, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UnSubQuote', index=2, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HandicapQuota', index=3, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Kline', index=4, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TickInfo', index=5, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MinuteQuote', index=6, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BuySellList', index=7, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BrokerInfo', index=8, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HistoryKline', index=9, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HistoryTickInfo', index=10, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PopularIndustry', index=11, number=100,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PopularConcept', index=12, number=101,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AllSectorQuota', index=13, number=102,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IndustryQuota', index=14, number=103,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ConceptQuota', index=15, number=104,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IndexQuota', index=16, number=105,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IndexConstituent', index=17, number=106,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NewSharesListed', index=18, number=107,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='Warrant', index=19, number=108,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AhStock', index=20, number=109,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WarrantAssetInfo', index=21, number=110,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BasicAssetInfo', index=22, number=200,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BasicSubMarketInfo', index=23, number=201,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AssetInfoByCodeList', index=24, number=202,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TransactionStat', index=25, number=300,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DicData', index=26, number=400,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STOCK_BACK_TEST', index=27, number=901,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ClearStock', index=28, number=500,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ExchangeRate', index=29, number=501,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=488,
  serialized_end=1041,
)
_sym_db.RegisterEnumDescriptor(_CMD)

Cmd = enum_type_wrapper.EnumTypeWrapper(_CMD)
_CODE = _descriptor.EnumDescriptor(
  name='Code',
  full_name='StockCommon.Code',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_INVOKER', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AGRUMENT_ERROR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKOWN_EXCEPTION', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PASSWARD_ERROR', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HAS_LOGIN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOGIN_FAIL', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_LOGIN', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMEOUT', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1044,
  serialized_end=1199,
)
_sym_db.RegisterEnumDescriptor(_CODE)

Code = enum_type_wrapper.EnumTypeWrapper(_CODE)
_MARKET = _descriptor.EnumDescriptor(
  name='Market',
  full_name='StockCommon.Market',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CN', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='US', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QS', index=4, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NS', index=5, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='AS', index=6, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PS', index=7, number=33,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BS', index=8, number=34,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VS', index=9, number=35,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SH', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SZ', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1201,
  serialized_end=1307,
)
_sym_db.RegisterEnumDescriptor(_MARKET)

Market = enum_type_wrapper.EnumTypeWrapper(_MARKET)
_LANGUAGE = _descriptor.EnumDescriptor(
  name='Language',
  full_name='StockCommon.Language',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ZH', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1309,
  serialized_end=1343,
)
_sym_db.RegisterEnumDescriptor(_LANGUAGE)

Language = enum_type_wrapper.EnumTypeWrapper(_LANGUAGE)
_QUOTETYPE = _descriptor.EnumDescriptor(
  name='QuoteType',
  full_name='StockCommon.QuoteType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NULL', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIN1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIN3', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIN5', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIN10', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIN15', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIN30', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOUR1', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOUR2', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HOUR4', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DAY1', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DAY5', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='WEEK1', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MONTH1', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='QUARTER1', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YEAR1', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1346,
  serialized_end=1531,
)
_sym_db.RegisterEnumDescriptor(_QUOTETYPE)

QuoteType = enum_type_wrapper.EnumTypeWrapper(_QUOTETYPE)
MOD_NONE = 0
SUB = 1
HEART_BEAT = 3
LOGIN = 20
HANDICAP = 4
PLATE = 5
ASSETINFO = 6
TRANS_STA = 7
DATA_DIC = 8
QUANT_FACTOR = 9
ACTION = 100
RAM_MOD = 200
SUB_TYPE_NONE = 0
QUOTE = 1
TICK = 2
BROKER = 3
ORDER = 4
CMD_NONE = 0
SubQuote = 10
UnSubQuote = 11
HandicapQuota = 21
Kline = 22
TickInfo = 23
MinuteQuote = 24
BuySellList = 25
BrokerInfo = 26
HistoryKline = 27
HistoryTickInfo = 28
PopularIndustry = 100
PopularConcept = 101
AllSectorQuota = 102
IndustryQuota = 103
ConceptQuota = 104
IndexQuota = 105
IndexConstituent = 106
NewSharesListed = 107
Warrant = 108
AhStock = 109
WarrantAssetInfo = 110
BasicAssetInfo = 200
BasicSubMarketInfo = 201
AssetInfoByCodeList = 202
TransactionStat = 300
DicData = 400
STOCK_BACK_TEST = 901
ClearStock = 500
ExchangeRate = 501
SUCCESS = 0
NO_INVOKER = 1
AGRUMENT_ERROR = 2
UNKOWN_EXCEPTION = 3
PASSWARD_ERROR = 4
HAS_LOGIN = 5
LOGIN_FAIL = 6
NO_LOGIN = 7
TIMEOUT = 8
NONE = 0
CN = 1
HK = 2
US = 3
QS = 30
NS = 31
AS = 32
PS = 33
BS = 34
VS = 35
SH = 10
SZ = 11
ZH = 0
TW = 1
EN = 2
NULL = 0
MIN1 = 1
MIN3 = 2
MIN5 = 3
MIN10 = 4
MIN15 = 5
MIN30 = 6
HOUR1 = 7
HOUR2 = 8
HOUR4 = 9
DAY1 = 10
DAY5 = 11
WEEK1 = 12
MONTH1 = 13
QUARTER1 = 14
YEAR1 = 15



_LOGIN = _descriptor.Descriptor(
  name='Login',
  full_name='StockCommon.Login',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='token', full_name='StockCommon.Login.token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deviceId', full_name='StockCommon.Login.deviceId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='macAddress', full_name='StockCommon.Login.macAddress', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipAddress', full_name='StockCommon.Login.ipAddress', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sysVersion', full_name='StockCommon.Login.sysVersion', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='platform', full_name='StockCommon.Login.platform', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='phoneModel', full_name='StockCommon.Login.phoneModel', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='srvType', full_name='StockCommon.Login.srvType', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='StockCommon.Login.username', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='StockCommon.Login.password', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='userId', full_name='StockCommon.Login.userId', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=34,
  serialized_end=240,
)

DESCRIPTOR.message_types_by_name['Login'] = _LOGIN
DESCRIPTOR.enum_types_by_name['Mod'] = _MOD
DESCRIPTOR.enum_types_by_name['SubType'] = _SUBTYPE
DESCRIPTOR.enum_types_by_name['Cmd'] = _CMD
DESCRIPTOR.enum_types_by_name['Code'] = _CODE
DESCRIPTOR.enum_types_by_name['Market'] = _MARKET
DESCRIPTOR.enum_types_by_name['Language'] = _LANGUAGE
DESCRIPTOR.enum_types_by_name['QuoteType'] = _QUOTETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Login = _reflection.GeneratedProtocolMessageType('Login', (_message.Message,), {
  'DESCRIPTOR' : _LOGIN,
  '__module__' : 'stock_comm_pb2'
  # @@protoc_insertion_point(class_scope:StockCommon.Login)
  })
_sym_db.RegisterMessage(Login)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
